pub struct UnknownModel {
pub model: String,
}Expand description
Returned when a model id is not in the price table.
Fields
model: StringTrait Implementations
Sourceimpl Clone for UnknownModel
impl Clone for UnknownModel
Sourcefn clone(&self) -> UnknownModel
fn clone(&self) -> UnknownModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnknownModel
impl Debug for UnknownModel
Sourceimpl Display for UnknownModel
impl Display for UnknownModel
Sourceimpl Error for UnknownModel
impl Error for UnknownModel
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<UnknownModel> for CheckError
impl From<UnknownModel> for CheckError
Sourcefn from(e: UnknownModel) -> Self
fn from(e: UnknownModel) -> Self
Converts to this type from the input type.
Sourceimpl From<UnknownModel> for EstimateError
impl From<UnknownModel> for EstimateError
Sourcefn from(e: UnknownModel) -> Self
fn from(e: UnknownModel) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for UnknownModel
impl PartialEq for UnknownModel
Sourcefn eq(&self, other: &UnknownModel) -> bool
fn eq(&self, other: &UnknownModel) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnknownModel